@@ -675,7 +675,7 @@ map_data[0])
             self.map.bluemarble()
         if self.background == 'etopo':
             self.map.etopo()
-        if self.background == 'GIS':
+        if self.background.split(',')[0] == 'GIS':
             h0 = float(self.lat[-1] - self.lat[0])
             w0 = float(self.lon[-1] - self.lon[0])
             ff = h0/w0      # form factor
@@ -683,15 +683,16 @@ map_data[0])
             size = "%d,%d" % (1024, height)
             # basemap_url = "http://server.arcgisonline.com/ArcGIS/rest/services/World_Topo_Map/MapServer/export?\
             # basemap_url = "http://server.arcgisonline.com/ArcGIS/rest/services/World_Imagery/MapServer/export?\
-            basemap_url = "http://server.arcgisonline.com/ArcGIS/rest/services/World_Street_Map/MapServer/export?\
-bbox=%s,%s,%s,%s&\
-bboxSR=4326&\
-imageSR=4326&\
-size=%s&\
-dpi=%d&\
-format=png24&\
-f=image" % (self.lon[0], self.lat[0], self.lon[-1], self.lat[-1], size, self.dpi)
-            self.map.imshow(imread(urlopen(basemap_url)), origin='upper')
+#             basemap_url = "http://server.arcgisonline.com/ArcGIS/rest/services/World_Street_Map/MapServer/export?\
+# bbox=%s,%s,%s,%s&\
+# bboxSR=4326&\
+# imageSR=4326&\
+# size=%s&\
+# dpi=%d&\
+# format=png24&\
+# f=image" % (self.lon[0], self.lat[0], self.lon[-1], self.lat[-1], size, self.dpi)
+#             print(self.lon[0], self.lat[0], self.lon[-1], self.lat[-1], size, self.dpi)
+            self.map.imshow(imread(self.background.split(',')[1]), origin='upper')
 
         #logo
         if self.logo:
